@@ -4,10 +4,11 @@ sys.path.append("../")
 from chessdotcom.client import *
 from chessdotcom import ChessDotComResponse
 from chessdotcom import Client
-Client.session.headers.update(**{"User-Agent": "My Python Application. Contact me at email@example.com"})
 
 def test_endpoints():
 
+    Client.headers['user-agent'] = 'my python app'
+
     data = get_player_profile("fabianocaruana")
     assert(isinstance(data, ChessDotComResponse))
     print(data.__dict__.keys())
